@@ -34,7 +34,7 @@ def maybe_get_users_list(timeout):
 
 
 def get_pr(project):
-    branch_name = git.current_branch_name()
+    branch_name = git.current_branch_name(project)
     pull = github.get_pr_from_branch(project, branch_name)
 
     if pull.totalCount:
